PROGRAM Compute_Coma_SZProfiles
! A code for computing:
! 1st column: x=r/r500
! 2nd column: SZ profile in RJ temperature [uK]
! E. Komatsu, November 20, 2011
  IMPLICIT none
  double precision :: xin=0d0,xout=6d0
  double precision :: h0=0.7d0 ! hubble=0.7
  double precision :: y,Tsz,tol=1d-6
  double precision :: p0,alpha,beta,gamma,rs
  double precision :: r500,da,para(6),pe,pe2d
  integer :: i
  double precision :: rombint
  external pe
  r500=1.037d0 ! h^-1 Mpc; computed from M500=6.61d14 h^-1 Msun. 
               ! M500 is from M500-Tx relation of Vikhlinin et al with Tx=8.4keV
  print*,'r500=',r500,' h^-1 Mpc'
  da=67.363  ! h^-1 Mpc; for OmegaM=0.277 and z=0.0231
  print*,'theta500=',r500/da*10800d0/3.14159d0,' arcmin'
  print*,'pressure profile is cut at r/r500=',xout
!!$ GNFW parameters [provided by A.Finoguenov]
  p0=6.1135007E-11*6.24d11 ! sqrt(h/0.72) eV cm^-3
  alpha=1.20d0
  beta=5.49d0 ! fixed when fitted to the measured Pe profile
  gamma=-6.9427d-2
  rs=0.99d0*0.72d0 ! h^-1 Mpc
  open(1,file='x_tsz_coma.txt')
  do i=1,1000
     y=(xin+1d-3*dble(i)*(xout-xin)) ! y=theta/theta500
     para=(/y*r500,p0,rs,alpha,beta,gamma/)
     pe2d=(1d0/h0)*rombint(pe,-dsqrt(xout**2d0-y**2d0)*r500,dsqrt(xout**2d0-y**2d0)*r500,tol,6,para)
     Tsz=-2d0*273d0*(pe2d/25d0) ! uK
     write(1,'(2E18.5)')y,tsz
  enddo
  close(1)
END PROGRAM Compute_Coma_SZProfiles
!-----------------------------------------------------------------------------
DOUBLE PRECISION FUNCTION pe(l,y) ! l is in units of h^-1 Mpc
! pe = electron pressure
  IMPLICIT none
  double precision :: l,r,y(6) ! l, r and y(1) are in units of h^-1 Mpc
  double precision :: p0,alpha,beta,gamma,rs
  r=dsqrt(l**2d0+y(1)**2d0)
  p0=y(2)
  rs=y(3)
  alpha=y(4)
  beta=y(5)
  gamma=y(6)
  pe=p0*(r/rs)**(-gamma)*(1d0+(r/rs)**alpha)**((gamma-beta)/alpha) ! eV cm^-3, electron pressure
  return
END FUNCTION pe
