double precision FUNCTION rombint(f,a,b,tol,npara,para)
!  Rombint returns the integral from a to b of using Romberg integration.
!  The method converges provided that f(x) is continuous in (a,b).
!  f must be double precision and must be declared external in the calling
!  routine.  tol indicates the desired relative accuracy in the integral.
!
  IMPLICIT none
  double precision, intent(IN) :: a,b,tol
  integer, intent(IN) :: npara
  double precision, dimension(npara), intent(IN) :: para
!  INTERFACE
!     double precision FUNCTION f(x,para)
!       IMPLICIT NONE
!       double precision :: x
!       double precision, dimension(:) :: para
!     END FUNCTION f
!  END INTERFACE
  double precision :: f
  external f
  integer :: MAXITER=40,MAXJ=5
  double precision, dimension(:), allocatable :: g
  double precision :: h,error,fourj,g0,g1,gmax
  integer :: nint,i,j,k,jmax
  allocate(g(MAXJ+1))
!
  h=0.5d0*(b-a)
  gmax=h*(f(a,para)+f(b,para))
  g(1)=gmax
  nint=1
  error=1.0d20
  i=0
10 i=i+1 
  if (i.gt.MAXITER.or.(i.gt.5.and.abs(error).lt.tol)) go to 40
!  Calculate next trapezoidal rule approximation to integral.
  g0=0.0d0
  do k=1,nint
     g0=g0+f(a+(k+k-1)*h,para)
  enddo
  g0=0.5d0*g(1)+h*g0
  h=0.5d0*h
  nint=nint+nint
  jmax=min(i,MAXJ)
  fourj=1.0d0
  do j=1,jmax
!  Use Richardson extrapolation.
     fourj=4.0d0*fourj
     g1=g0+(g0-g(j))/(fourj-1.0d0)
     g(j)=g0
     g0=g1
  enddo
  if (abs(g0).gt.tol) then
     error=1.0d0-gmax/g0
  else
     error=gmax
  end if
  gmax=g0
  g(jmax+1)=g0
  go to 10
40 rombint=g0
  if (i.gt.MAXITER.and.abs(error).gt.tol) then
     write(*,*) 'Rombint failed to converge; integral, error=',rombint,error
  endif
  return
end FUNCTION rombint
